Feast Python API Documentation
=============================


Feature Store
---------------------------

.. automodule:: feast.feature_store
   :members:
   :undoc-members:
   :show-inheritance:

Config
==================

.. automodule:: feast.repo_config
    :members:
    :exclude-members: load_repo_config

Data Source
==================

.. automodule:: feast.data_source
    :members:


Entity
==================

.. automodule:: feast.entity
    :inherited-members:
    :members:


Feature View
==================

.. automodule:: feast.feature_view
    :members:

Feature Table
==================

.. automodule:: feast.feature_table
    :members:

Feature
==================

.. automodule:: feast.feature
    :inherited-members:
    :members:
